# Aloha Flask Creator

这是一个简单的命令行项目创建工具，用于根据 `https://github.com/TheadoreL/flask-vue-template` 这个模板来创建一个Flask 和 Vue 结合的项目

## 安装

使用 `pip` 安装:

```bash
pip install aloha-flask-creator

```

## 使用

安装后用以下命令使用该工具

```bash
aloha-flask-creator
```

示例：

```
$ aloha-flask-creator
Please enter the name of the new project: my-flask-project
New project created at: my-flask-project
```